@@ -20,28 +20,15 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-"""The module `flatools` contains functions that deal with flatten lists. The
-full list of available functions is:
-
-* `flatools.flatten_index(element, input_list)`
-* `flatools.flatten_join(*input_lists)`
-* `flatools.flatten_len(input_list)`
-* `flatools.flatten_max(input_list, *[, key, default])`
-* `flatools.flatten_min(input_list, *[, key, default])`
-* `flatools.flatten_mixed_type(input_list)`
-* `flatools.flatten_reverse(input_list)`
-* `flatools.flatten_single_type(input_list)`
-* `flatools.flatten_sorted(input_list, *[, key, reverse])`
-* `flatools.flatten_sum(input_list[, start])`
-* `flatools.flatten_zip_cycle(*input_lists)`
-* `flatools.flatten(input_list)`
-* `flatools.pflatten(input_list[, depth])`
+"""The module `flatools` contains functions that deal with flatten lists.
 
 All functions have a `__doc__` attribute with usage instructions.
 
 This library is published under the MIT License.
 """
 
+from numbers import Number
+
 
 def flatten(input_list: list) -> list:
     r"""flatools.flatten(input_list)
@@ -206,8 +193,8 @@ def flatten_sum(input_list: list, start=0):
 def flatten_len(input_list: list) -> int:
     r"""flatools.flatten_len(input_list)
 
-    Returns the flatten_length of a flatten list (that is, it counts all
-    elements in all of its subslists). Usage:
+    Returns the length of a flatten list (that is, it counts all elements in
+    all of its subslists). Usage:
 
     >>> alist = [[1, 2], [3, 4], [5, 6]]
     >>> flatools.flatten_len(alist)
@@ -227,8 +214,8 @@ def flatten_len(input_list: list) -> int:
 def flatten_index(element, input_list: list) -> int:
     r"""flatools.flatten_index(input_list)
 
-    Returns the length of a flatten list (that is, it counts all elements in
-    all of its subslists). Usage:
+    Returns the index of the first instance of an element in a flatten list.
+    Usage:
 
     >>> alist = [[1, 2], [3, 4], [5, 6]]
     >>> flatools.flatten_index(3, alist)
@@ -257,8 +244,8 @@ def flatten_index(element, input_list: list) -> int:
 def flatten_zip_cycle(*input_lists) -> tuple:
     r"""flatools.flatten_zip_cycle(*input_lists)
 
-    This function is very nearly identical to flatools.flatten_zip_cycle except
-    that it also flattens all lists before zipping and cycling them. Usage:
+    This function is nearly identical to iterz.zip_cycle except that it also
+    flattens all lists before zipping and cycling them. Usage:
 
     >>> alist = [1, 2]
     >>> blist = [4, [5, 6, 7], 8]
@@ -397,10 +384,10 @@ def flatten_max(input_list: list,
                 *,
                 key: 'function' = None,
                 default=None
-                ) -> list:
+                ) -> Number:
     r"""flatools.flatten_max(input_list, *[, key, default])
 
-    Finds the largest element of a  flattened list containing any number of
+    Finds the largest element of a flattened list containing any number of
     nested subslists. Usage:
 
     >>> alist = [[1, 4], [5, 7], [2], [9, 6, 10], [8, 3]]
@@ -445,8 +432,8 @@ def flatten_max(input_list: list,
     if not isinstance(input_list, list):
         raise TypeError('\'input_list\' must be \'list\'')
     # not very elegant, but max(input, key=None) raises "TypeError: 'NoneType'
-    # object is not callable". Meanwhile, sorted(input, key=None) works exactly
-    # as expected.
+    # object is not callable. Other functions such as sorted(input, key=None)
+    # work exactly as expected when key=None.
     if key:
         return max(flatten(input_list), key=key, default=default)
     else:
@@ -457,7 +444,7 @@ def flatten_min(input_list: list,
                 *,
                 key: 'function' = None,
                 default=None
-                ) -> list:
+                ) -> Number:
     r"""flatools.flatten_min(input_list, *[, key, default])
 
     Finds the smallest element of a  flattened list containing any number of
